====================
HeatmiserController
====================

Python implementation of Heatmiser protocol for serial connected devices.

Originally written to get direct access to heatmiser devices. It was created for reading and controlling Slimline-N and Slimline-HWN  thermostats connected to RS232 serial port through RS485 adapter.

Documentation used
==================

* `Heatmiser V3 System Protocol v3.9`

Supported Hardware
==================

Master
------

* 

Slave
-----

* `PRT-E <https://www.heatmiser.com/en/slimline-thermostat-series-2/>`_ - Slimline N - 12v Programmable Room Thermostat.
* `PRT-HW <https://www.heatmiser.com/en/slimline-thermostat-series-2/>`_ - Slimline HWN - 12v Programmable Room Thermostat.
* Other heatmiser stats could be added with additional configration.

Usage
=====
